@@ -76,7 +76,7 @@ check_param_list <- function(pm, type = "string", check_paths = FALSE, correct =
   
   # -- Parameters of length 1: check length
   pm_length1 <- c(
-    "preprocess", "online", "downloader", "overwrite_safe", "rm_safe",
+    "preprocess", "online", "order_lta", "downloader", "overwrite_safe", "rm_safe",
     "step_atmcorr", "max_cloud_safe", "timeperiod", "extent_name", "index_source",
     "mask_type", "max_mask", "mask_smooth", "mask_buffer", "clip_on_extent",
     "extent_as_mask", "reference_path", "res_s2", "unit", "proj", "resampling",
@@ -132,6 +132,9 @@ check_param_list <- function(pm, type = "string", check_paths = FALSE, correct =
   # -- online --
   
   
+  # -- order_lta --
+  
+  
   # -- downloader --
   if (!pm$downloader %in% c("builtin", "aria2")) {
     print_message(
